@@ -42,8 +42,8 @@ void Identity::create()
     Q_EMIT info(i18n("Setting up identity..."));
 
     // store identity information
-    m_identity->setIdentityName(identityName());
-
+    m_identityName = identityName();
+    m_identity->setIdentityName(m_identityName);
     auto manager = KIdentityManagement::IdentityManager::self();
     if (!manager->setAsDefault(m_identity->uoid())) {
         qCWarning(ACCOUNTWIZARD_LOG) << "Impossible to find identity";
@@ -60,7 +60,7 @@ QString Identity::identityName() const
     if (name.isEmpty()) {
         name = i18nc("Default name for new email accounts/identities.", "Unnamed");
 
-        QString idName = m_identity->primaryEmailAddress();
+        const QString idName = m_identity->primaryEmailAddress();
         int pos = idName.indexOf(QLatin1Char('@'));
         if (pos != -1) {
             name = idName.mid(0, pos);
@@ -85,8 +85,8 @@ QString Identity::identityName() const
 void Identity::destroy()
 {
     auto manager = KIdentityManagement::IdentityManager::self();
-    if (!manager->removeIdentityForced(m_identity->identityName())) {
-        qCWarning(ACCOUNTWIZARD_LOG) << " impossible to remove identity " << m_identity->identityName();
+    if (!manager->removeIdentityForced(m_identityName)) {
+        qCWarning(ACCOUNTWIZARD_LOG) << " impossible to remove identity " << m_identityName;
     }
     manager->commit();
     m_identity = nullptr;
